import { Input, Modal } from 'antd';
import { auto } from 'manate/react.js';
import React, { useRef, useState } from 'react';
const PromptModals = (props) => {
    const { store } = props;
    const { modals } = store;
    const emojiInput = useRef(null);
    const faInput = useRef(null);
    const [emojiValue, setEmojiValue] = useState('');
    const [faValue, setFaValue] = useState('');
    const handleEmojiOK = () => {
        modals.emoji.close();
        const value = emojiValue.trim();
        if (value.length > 0) {
            const editor = store.editor;
            const mainSelection = editor.state.selection.main;
            editor.dispatch({
                changes: {
                    from: mainSelection.from,
                    to: mainSelection.to,
                    insert: `:${value}:`,
                },
                selection: { anchor: mainSelection.head + value.length + 2 },
            });
        }
        setEmojiValue('');
    };
    const handleFaOK = () => {
        modals.fontAwesome.close();
        const value = faValue.trim();
        if (value.length > 0) {
            const editor = store.editor;
            const mainSelection = editor.state.selection.main;
            editor.dispatch({
                changes: {
                    from: mainSelection.from,
                    to: mainSelection.to,
                    insert: `:fa-${value}:`,
                },
                selection: { anchor: mainSelection.head + value.length + 5 },
            });
        }
        setFaValue('');
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(Modal, { open: modals.emoji.isOpen, onCancel: () => modals.emoji.close(), onOk: () => handleEmojiOK(), maskClosable: true, centered: true, afterOpenChange: (open) => {
                if (open) {
                    emojiInput.current?.focus();
                }
            } },
            React.createElement("div", { style: { textAlign: 'center' } },
                React.createElement("p", null,
                    React.createElement("img", { src: "https://markpluslabs.github.io/react-markplus/icon.svg", width: "64" })),
                React.createElement("h2", null, "Please enter an emoji code:"),
                React.createElement("p", null, `Examples: "smile", "whale", "santa", "panda_face", "dog", "truck"
...`),
                React.createElement("p", null,
                    "For a complete list, please check",
                    ' ',
                    React.createElement("a", { href: "https://github.com/ikatyang/emoji-cheat-sheet/blob/master/README.md", target: "_blank", rel: "noreferrer" }, "Emoji Cheat Sheet"),
                    "."),
                React.createElement("div", null,
                    React.createElement(Input, { ref: emojiInput, value: emojiValue, onChange: (e) => setEmojiValue(e.target.value), placeholder: "smile", onKeyUp: (e) => {
                            if (e.key === 'Enter') {
                                handleEmojiOK();
                            }
                        } })))),
        React.createElement(Modal, { open: modals.fontAwesome.isOpen, onCancel: () => modals.fontAwesome.close(), onOk: () => handleFaOK(), maskClosable: true, centered: true, afterOpenChange: (open) => {
                if (open) {
                    faInput.current?.focus();
                }
            } },
            React.createElement("div", { style: { textAlign: 'center' } },
                React.createElement("p", null,
                    React.createElement("img", { src: "https://markpluslabs.github.io/react-markplus/icon.svg", width: "64" })),
                React.createElement("h2", null, "Please enter a Font Awesome code:"),
                React.createElement("p", null, `Examples: "cloud", "flag", "car", "truck", "heart", "dollar" ...`),
                React.createElement("p", null,
                    "For a complete list, please check",
                    ' ',
                    React.createElement("a", { href: "https://github.com/gluons/Font-Awesome-Icon-Chars/blob/master/character-list/character-list.yaml", target: "_blank", rel: "noreferrer" }, "Font Awesome Icons"),
                    "."),
                React.createElement("div", null,
                    React.createElement(Input, { ref: faInput, placeholder: "heart", value: faValue, onChange: (e) => setFaValue(e.target.value), onKeyUp: (e) => {
                            if (e.key === 'Enter') {
                                handleFaOK();
                            }
                        } }))))));
};
export default auto(PromptModals);
