import { auto } from 'manate/react.js';
import React, { cloneElement } from 'react';
const Toolbar = (props) => {
    const { store } = props;
    const { modals } = store;
    const stylingClicked = (modifier) => {
        const editor = store.editor;
        let mainSelection = editor.state.selection.main;
        if (mainSelection.empty) {
            const word = editor.state.wordAt(mainSelection.head);
            if (word) {
                editor.dispatch({
                    selection: { anchor: word.from, head: word.to },
                });
            }
        }
        mainSelection = editor.state.selection.main; // don't forget to update this variable
        editor.dispatch({
            changes: {
                from: mainSelection.from,
                to: mainSelection.to,
                insert: `${modifier}${editor.state.sliceDoc(mainSelection.from, mainSelection.to)}${modifier}`,
            },
        });
    };
    const listClicked = (prefix) => {
        const editor = store.editor;
        const startLine = editor.state.doc.lineAt(editor.state.selection.main.from);
        const endLine = editor.state.doc.lineAt(editor.state.selection.main.to);
        for (let i = startLine.number; i <= endLine.number; i++) {
            const line = editor.state.doc.line(i);
            editor.dispatch({
                changes: {
                    from: line.from,
                    to: line.from,
                    insert: prefix,
                },
            });
        }
    };
    const insertFence = (type, sample) => {
        const editor = store.editor;
        const mainSelection = editor.state.selection.main;
        const text = editor.state.sliceDoc(mainSelection.from, mainSelection.to) || sample;
        editor.dispatch({
            changes: {
                from: mainSelection.from,
                to: mainSelection.to,
                insert: `\n\`\`\`${type}\n${text}\n\`\`\`\n`,
            },
        });
    };
    return (React.createElement("div", { className: "toolbar" }, store.preferences.toolbarItems.map((item, index) => {
        let reactElement;
        if (typeof item === 'string') {
            switch (item) {
                case 'about': {
                    reactElement = (React.createElement("img", { src: "https://markpluslabs.github.io/react-markplus/icon.svg", className: "about-icon", onClick: () => modals.about.open(), title: "About" }));
                    break;
                }
                case '|': {
                    reactElement = React.createElement("span", { className: "dividor" }, "|");
                    break;
                }
                case 'bold': {
                    reactElement = (React.createElement("i", { title: "Bold", className: `fa fa-bold`, onClick: () => stylingClicked('**') }));
                    break;
                }
                case 'italic': {
                    reactElement = (React.createElement("i", { title: "Italic", className: `fa fa-italic`, onClick: () => stylingClicked('*') }));
                    break;
                }
                case 'strikethrough': {
                    reactElement = (React.createElement("i", { title: "Strikethrough", className: `fa fa-strikethrough`, onClick: () => stylingClicked('~~') }));
                    break;
                }
                case 'underline': {
                    reactElement = (React.createElement("i", { title: "Underline", className: `fa fa-underline`, onClick: () => stylingClicked('++') }));
                    break;
                }
                case 'mark': {
                    reactElement = (React.createElement("i", { title: "Mark", className: `fa fa-marker`, onClick: () => stylingClicked('==') }));
                    break;
                }
                case 'emoji': {
                    reactElement = (React.createElement("i", { title: "Emoji", className: "fa fa-regular fa-smile", onClick: () => modals.emoji.open() }));
                    break;
                }
                case 'fontawesome': {
                    reactElement = (React.createElement("i", { title: "Font awesome", className: "fa fa-regular fa-flag", onClick: () => modals.fontAwesome.open() }));
                    break;
                }
                case 'quote': {
                    reactElement = (React.createElement("i", { title: 'Quote', className: `fa fa-quote-left`, onClick: () => listClicked('> ') }));
                    break;
                }
                case 'unordered-list': {
                    reactElement = (React.createElement("i", { title: 'Unordered list', className: `fa fa-list-ul`, onClick: () => listClicked('- ') }));
                    break;
                }
                case 'ordered-list': {
                    reactElement = (React.createElement("i", { title: 'Ordered list', className: `fa fa-list-ol`, onClick: () => listClicked('1. ') }));
                    break;
                }
                case 'unchecked-list': {
                    reactElement = (React.createElement("i", { title: 'Unchecked list', className: `fa fa-regular fa-square`, onClick: () => listClicked('- [ ] ') }));
                    break;
                }
                case 'checked-list': {
                    reactElement = (React.createElement("i", { title: 'Checked list', className: `fa fa-regular fa-check-square`, onClick: () => listClicked('- [x] ') }));
                    break;
                }
                case 'link': {
                    reactElement = (React.createElement("i", { title: "Link", className: "fa fa-link", onClick: () => {
                            const editor = store.editor;
                            const mainSelection = editor.state.selection.main;
                            const text = editor.state.sliceDoc(mainSelection.from, mainSelection.to) || 'link';
                            editor.dispatch({
                                changes: {
                                    from: mainSelection.from,
                                    to: mainSelection.to,
                                    insert: `[${text}](https://github.com/markpluslabs/react-markplus/)`,
                                },
                            });
                        } }));
                    break;
                }
                case 'image': {
                    reactElement = (React.createElement("i", { title: "Image", className: "fa fa-regular fa-image", onClick: () => {
                            const editor = store.editor;
                            const mainSelection = editor.state.selection.main;
                            const text = editor.state.sliceDoc(mainSelection.from, mainSelection.to) || 'image';
                            editor.dispatch({
                                changes: {
                                    from: mainSelection.from,
                                    to: mainSelection.to,
                                    insert: `![${text}](https://markpluslabs.github.io/react-markplus/icon.svg)`,
                                },
                            });
                        } }));
                    break;
                }
                case 'code': {
                    reactElement = (React.createElement("i", { title: "Code", className: "fa fa-code", onClick: () => {
                            const editor = store.editor;
                            const mainSelection = editor.state.selection.main;
                            const text = editor.state.sliceDoc(mainSelection.from, mainSelection.to) || "console.log('Hello, world!');";
                            editor.dispatch({
                                changes: {
                                    from: mainSelection.from,
                                    to: mainSelection.to,
                                    insert: `\n\`\`\`\n${text}\n\`\`\`\n`,
                                },
                            });
                        } }));
                    break;
                }
                case 'table': {
                    reactElement = (React.createElement("i", { title: "Table", className: "fa fa-table", onClick: () => {
                            const sample = `
header 1 | header 2
---|---
row 1 col 1 | row 1 col 2
row 2 col 1 | row 2 col 2`.trim();
                            const editor = store.editor;
                            const cursorPos = editor.state.selection.main.head;
                            const currentLine = editor.state.doc.lineAt(cursorPos);
                            const isAtLineStart = cursorPos === currentLine.from;
                            if (isAtLineStart) {
                                editor.dispatch({
                                    changes: {
                                        from: currentLine.from,
                                        to: currentLine.from,
                                        insert: `\n${sample}\n\n`,
                                    },
                                });
                            }
                            else {
                                editor.dispatch({
                                    changes: {
                                        from: currentLine.to,
                                        to: currentLine.to,
                                        insert: `\n\n${sample}\n`,
                                    },
                                });
                            }
                        } }));
                    break;
                }
                case 'math': {
                    reactElement = (React.createElement("i", { title: "Math", className: "fa fa-square-root-variable", onClick: () => {
                            const editor = store.editor;
                            const mainSelection = editor.state.selection.main;
                            const text = editor.state.sliceDoc(mainSelection.from, mainSelection.to) || 'E = mc^2';
                            editor.dispatch({
                                changes: {
                                    from: mainSelection.from,
                                    to: mainSelection.to,
                                    insert: `\n\`\`\`math\n${text}\n\`\`\`\n`,
                                },
                            });
                        } }));
                    break;
                }
                case 'flowchart': {
                    reactElement = (React.createElement("i", { title: "flowchart", className: "fa fa-diagram-project", onClick: () => insertFence('flowchart', 'A -> B') }));
                    break;
                }
                default: {
                    throw new Error(`Unknown toolbar item: ${item}`);
                }
            }
        }
        else {
            reactElement = item;
        }
        return cloneElement(reactElement, { key: `item-${index}` });
    })));
};
export default auto(Toolbar);
